@@ -24,5 +24,5 @@ package org.jboss.classfilewriter.code;
  *
  */
 public enum StackFrameType {
-    SAME_FRAME, SAME_LOCALS_1_STACK, CHOP_FRAME, SAME_FRAME_EXTENDED, APPEND_FRAME, FULL_FRAME;
+    SAME_FRAME, SAME_LOCALS_1_STACK, CHOP_FRAME, SAME_FRAME_EXTENDED, APPEND_FRAME, FULL_FRAME
 }
